==> calligra-2.4.3.tar.xz: calligra-2.4.3/stage/plugins/pageeffects/matrixwipe/boxsnakes/KPrBoxSnakesWipeEffectFactory.h <==
/* This file is part of the KDE project
   Copyright (C) 2008 Marijn Kruisselbrink <mkruisselbrink@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPRBOXSNAKESWIPEEFFECTFACTORY_H
#define KPRBOXSNAKESWIPEEFFECTFACTORY_H

#include <KPrPageEffectFactory.h>

class KPrBoxSnakesWipeEffectFactory : public KPrPageEffectFactory
{
public:
    KPrBoxSnakesWipeEffectFactory();
    virtual ~KPrBoxSnakesWipeEffectFactory();
    virtual QString subTypeName(int subType) const;

    enum SubType {
        TwoBoxTopIn,
        TwoBoxBottomIn,
        TwoBoxLeftIn,
        TwoBoxRightIn,
        FourBoxVerticalIn,
        FourBoxHorizontalIn,
        TwoBoxTopOut,
        TwoBoxBottomOut,
        TwoBoxLeftOut,
        TwoBoxRightOut,
        FourBoxVerticalOut,
        FourBoxHorizontalOut
    };
};

#endif /* KPRBOXSNAKESWIPEEFFECTFACTORY_H */

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/plugins/pageeffects/matrixwipe/boxsnakes/KPrBoxSnakesWipeEffectFactory.h <==
/* This file is part of the KDE project
   Copyright (C) 2008 Marijn Kruisselbrink <mkruisselbrink@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPRBOXSNAKESWIPEEFFECTFACTORY_H
#define KPRBOXSNAKESWIPEEFFECTFACTORY_H

#include <KPrPageEffectFactory.h>

class KPrBoxSnakesWipeEffectFactory : public KPrPageEffectFactory
{
public:
    KPrBoxSnakesWipeEffectFactory();
    ~KPrBoxSnakesWipeEffectFactory() override;
    QString subTypeName(int subType) const override;

    enum SubType {
        TwoBoxTopIn,
        TwoBoxBottomIn,
        TwoBoxLeftIn,
        TwoBoxRightIn,
        FourBoxVerticalIn,
        FourBoxHorizontalIn,
        TwoBoxTopOut,
        TwoBoxBottomOut,
        TwoBoxLeftOut,
        TwoBoxRightOut,
        FourBoxVerticalOut,
        FourBoxHorizontalOut
    };
};

#endif /* KPRBOXSNAKESWIPEEFFECTFACTORY_H */
